@@ -1,13 +1,34 @@
 /*
- * Box.java
+ * java-gnome, a UI library for writing GTK and GNOME programs from Java!
  *
- * Copyright (c) 2007-2008 Operational Dynamics Consulting Pty Ltd
- * 
- * The code in this file, and the library it is a part of, are made available
- * to you by the authors under the terms of the "GNU General Public Licence,
- * version 2" plus the "Classpath Exception" (you may link to this code as a
- * library into other programs provided you don't make a derivation of it).
- * See the LICENCE file for the terms governing usage and redistribution.
+ * Copyright © 2007-2010 Operational Dynamics Consulting, Pty Ltd and Others
+ *
+ * The code in this file, and the program it is a part of, is made available
+ * to you by its authors as open source software: you can redistribute it
+ * and/or modify it under the terms of the GNU General Public License version
+ * 2 ("GPL") as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GPL for more details.
+ *
+ * You should have received a copy of the GPL along with this program. If not,
+ * see http://www.gnu.org/licenses/. The authors of this program may be
+ * contacted through http://java-gnome.sourceforge.net/.
+ *
+ * Linking this library statically or dynamically with other modules is making
+ * a combined work based on this library. Thus, the terms and conditions of
+ * the GPL cover the whole combination. As a special exception (the
+ * "Claspath Exception"), the copyright holders of this library give you
+ * permission to link this library with independent modules to produce an
+ * executable, regardless of the license terms of these independent modules,
+ * and to copy and distribute the resulting executable under terms of your
+ * choice, provided that you also meet, for each linked independent module,
+ * the terms and conditions of the license of that module. An independent
+ * module is a module which is not derived from or based on this library. If
+ * you modify this library, you may extend the Classpath Exception to your
+ * version of the library, but you are not obligated to do so. If you do not
+ * wish to do so, delete this exception statement from your version.
  */
 package org.gnome.gtk;
 
@@ -51,6 +72,8 @@ public abstract class Box extends Container
      * <code>packStart(child, true, true, 0)</code>; see the full
      * {@link #packStart(Widget, boolean, boolean, int) packStart()} for
      * details.</i>
+     * 
+     * @deprecated Use packStart(Widget, boolean, boolean, int) instead.
      */
     public void packStart(Widget child) {
         GtkBox.packStart(this, child, true, true, 0);
@@ -82,6 +105,7 @@ public abstract class Box extends Container
      *            <code>child</code> is the Widget at one of the start of the
      *            Box, then <code>padding</code> pixels are also put between
      *            the Widget and the leading edge.
+     * @since 4.0.1
      */
     public void packStart(Widget child, boolean expand, boolean fill, int padding) {
         GtkBox.packStart(this, child, expand, fill, padding);
@@ -96,6 +120,7 @@ public abstract class Box extends Container
      * {@link #packEnd(Widget, boolean, boolean, int) packEnd()} method for
      * details.</i>
      * 
+     * @deprecated Use packEnd(Widget, boolean, boolean, int) instead.
      * @since 4.0.6
      */
     public void packEnd(Widget child) {
@@ -119,8 +144,8 @@ public abstract class Box extends Container
      * Change the position of a Widget in the Box. The child will still be
      * packed with respect to the beginning (if
      * {@link #packStart(Widget, boolean, boolean, int) packStart()} was used)
-     * or end (if {@link #packEnd(Widget, boolean, boolean, int) packEnd() was
-     * used}) of the Box, and will be placed just after the Widget at
+     * or end (if {@link #packEnd(Widget, boolean, boolean, int) packEnd()}
+     * was used) of the Box, and will be placed just after the Widget at
      * <code>position</code>.
      * 
      * @since 4.0.8
@@ -128,4 +153,32 @@ public abstract class Box extends Container
     public void reorderChild(Widget child, int position) {
         GtkBox.reorderChild(this, child, position);
     }
+
+    /**
+     * Set the amount of spacing between the Widgets in the Box. The spacing
+     * is measured in pixels. By default this is <code>0</code>, but is
+     * actually whatever was set in the {@link HBox#HBox(boolean, int) HBox}
+     * or {@link VBox#VBox(boolean, int) VBox} constructor.
+     * 
+     * <p>
+     * Allowed values are <code>0</code> or greater.
+     * 
+     * @since 4.0.11
+     */
+    public void setSpacing(int spacing) {
+        if (spacing < 0) {
+            throw new IllegalArgumentException("spacing must be >= 0");
+        }
+        GtkBox.setSpacing(this, spacing);
+    }
+
+    /**
+     * Returns the amount of spacing that is set to be places between the
+     * Widgets that are in the Box. The amount is measured in pixels.
+     * 
+     * @since 4.0.11
+     */
+    public int getSpacing() {
+        return GtkBox.getSpacing(this);
+    }
 }
